====================================
WeRoBot
====================================

.. image:: https://img.shields.io/travis/offu/WeRoBot/master.svg?maxAge=3600&label=macOS
    :target: https://travis-ci.org/offu/WeRoBot
.. image:: https://img.shields.io/appveyor/ci/whtsky/WeRoBot/master.svg?maxAge=3600&label=Windows
    :target: https://ci.appveyor.com/project/whtsky/WeRoBot
.. image:: https://semaphoreci.com/api/v1/offu/werobot/branches/master/shields_badge.svg
    :target: https://semaphoreci.com/offu/werobot
.. image:: https://codecov.io/gh/offu/WeRoBot/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/offu/WeRoBot
.. image:: https://img.shields.io/badge/QQ%20Group-283206829-brightgreen.svg?logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64% %2BPC9zdmc%2B
    :target: https://jq.qq.com/?_wv=1027&k=449sXsV


.. image:: https://werobot-slackin.herokuapp.com/badge.svg
    :target: https://werobot-slackin.herokuapp.com

WeRoBot 是一个微信公众号开发框架，采用MIT协议发布。

文档在这里： https://werobot.readthedocs.org/zh_CN/latest/

安装
========

推荐使用 pip 进行安装 ::

    pip install werobot

Hello World
=============

一个非常简单的 Hello World 微信公众号，会对收到的所有文本消息回复 Hello World ::

    import werobot

    robot = werobot.WeRoBot(token='tokenhere')

    @robot.text
    def hello_world():
        return 'Hello World!'

    robot.run()
